#[non_exhaustive]pub struct CreateDomainLayoutInput {
pub domain_name: Option<String>,
pub layout_definition_name: Option<String>,
pub description: Option<String>,
pub display_name: Option<String>,
pub is_default: Option<bool>,
pub layout_type: Option<LayoutType>,
pub layout: Option<String>,
pub tags: Option<HashMap<String, String>>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.domain_name: Option<String>The unique name of the domain.
layout_definition_name: Option<String>The unique name of the layout.
description: Option<String>The description of the layout
display_name: Option<String>The display name of the layout
is_default: Option<bool>If set to true for a layout, this layout will be used by default to view data. If set to false, then the layout will not be used by default, but it can be used to view data by explicitly selecting it in the console.
layout_type: Option<LayoutType>The type of layout that can be used to view data under a Customer Profiles domain.
layout: Option<String>A customizable layout that can be used to view data under a Customer Profiles domain.
The tags used to organize, track, or control access for this resource.
Implementations
Sourceimpl CreateDomainLayoutInput
impl CreateDomainLayoutInput
Sourcepub fn domain_name(&self) -> Option<&str>
pub fn domain_name(&self) -> Option<&str>
The unique name of the domain.
Sourcepub fn layout_definition_name(&self) -> Option<&str>
pub fn layout_definition_name(&self) -> Option<&str>
The unique name of the layout.
Sourcepub fn description(&self) -> Option<&str>
pub fn description(&self) -> Option<&str>
The description of the layout
Sourcepub fn display_name(&self) -> Option<&str>
pub fn display_name(&self) -> Option<&str>
The display name of the layout
Sourcepub fn is_default(&self) -> Option<bool>
pub fn is_default(&self) -> Option<bool>
If set to true for a layout, this layout will be used by default to view data. If set to false, then the layout will not be used by default, but it can be used to view data by explicitly selecting it in the console.
Sourcepub fn layout_type(&self) -> Option<&LayoutType>
pub fn layout_type(&self) -> Option<&LayoutType>
The type of layout that can be used to view data under a Customer Profiles domain.
Sourcepub fn layout(&self) -> Option<&str>
pub fn layout(&self) -> Option<&str>
A customizable layout that can be used to view data under a Customer Profiles domain.
The tags used to organize, track, or control access for this resource.
Sourceimpl CreateDomainLayoutInput
impl CreateDomainLayoutInput
Sourcepub fn builder() -> CreateDomainLayoutInputBuilder
pub fn builder() -> CreateDomainLayoutInputBuilder
Creates a new builder-style object to manufacture CreateDomainLayoutInput.