#[non_exhaustive]pub struct CreateEventStreamInput {
pub domain_name: Option<String>,
pub uri: Option<String>,
pub event_stream_name: Option<String>,
pub tags: Option<HashMap<String, String>>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.domain_name: Option<String>The unique name of the domain.
uri: Option<String>The StreamARN of the destination to deliver profile events to. For example, arn:aws:kinesis:region:account-id:stream/stream-name
event_stream_name: Option<String>The name of the event stream.
The tags used to organize, track, or control access for this resource.
Implementations
Sourceimpl CreateEventStreamInput
impl CreateEventStreamInput
Sourcepub fn domain_name(&self) -> Option<&str>
pub fn domain_name(&self) -> Option<&str>
The unique name of the domain.
Sourcepub fn uri(&self) -> Option<&str>
pub fn uri(&self) -> Option<&str>
The StreamARN of the destination to deliver profile events to. For example, arn:aws:kinesis:region:account-id:stream/stream-name
Sourcepub fn event_stream_name(&self) -> Option<&str>
pub fn event_stream_name(&self) -> Option<&str>
The name of the event stream.
The tags used to organize, track, or control access for this resource.
Sourceimpl CreateEventStreamInput
impl CreateEventStreamInput
Sourcepub fn builder() -> CreateEventStreamInputBuilder
pub fn builder() -> CreateEventStreamInputBuilder
Creates a new builder-style object to manufacture CreateEventStreamInput.