#[non_exhaustive]pub struct CreateIntegrationWorkflowInput {
pub domain_name: Option<String>,
pub workflow_type: Option<WorkflowType>,
pub integration_config: Option<IntegrationConfig>,
pub object_type_name: Option<String>,
pub role_arn: Option<String>,
pub tags: Option<HashMap<String, String>>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.domain_name: Option<String>The unique name of the domain.
workflow_type: Option<WorkflowType>The type of workflow. The only supported value is APPFLOW_INTEGRATION.
integration_config: Option<IntegrationConfig>Configuration data for integration workflow.
object_type_name: Option<String>The name of the profile object type.
role_arn: Option<String>The Amazon Resource Name (ARN) of the IAM role. Customer Profiles assumes this role to create resources on your behalf as part of workflow execution.
The tags used to organize, track, or control access for this resource.
Implementations
Sourceimpl CreateIntegrationWorkflowInput
impl CreateIntegrationWorkflowInput
Sourcepub fn domain_name(&self) -> Option<&str>
pub fn domain_name(&self) -> Option<&str>
The unique name of the domain.
Sourcepub fn workflow_type(&self) -> Option<&WorkflowType>
pub fn workflow_type(&self) -> Option<&WorkflowType>
The type of workflow. The only supported value is APPFLOW_INTEGRATION.
Sourcepub fn integration_config(&self) -> Option<&IntegrationConfig>
pub fn integration_config(&self) -> Option<&IntegrationConfig>
Configuration data for integration workflow.
Sourcepub fn object_type_name(&self) -> Option<&str>
pub fn object_type_name(&self) -> Option<&str>
The name of the profile object type.
Sourcepub fn role_arn(&self) -> Option<&str>
pub fn role_arn(&self) -> Option<&str>
The Amazon Resource Name (ARN) of the IAM role. Customer Profiles assumes this role to create resources on your behalf as part of workflow execution.
The tags used to organize, track, or control access for this resource.
Sourceimpl CreateIntegrationWorkflowInput
impl CreateIntegrationWorkflowInput
Sourcepub fn builder() -> CreateIntegrationWorkflowInputBuilder
pub fn builder() -> CreateIntegrationWorkflowInputBuilder
Creates a new builder-style object to manufacture CreateIntegrationWorkflowInput.