#[non_exhaustive]pub struct CreateProfileInput {Show 26 fields
pub domain_name: Option<String>,
pub account_number: Option<String>,
pub additional_information: Option<String>,
pub party_type: Option<PartyType>,
pub business_name: Option<String>,
pub first_name: Option<String>,
pub middle_name: Option<String>,
pub last_name: Option<String>,
pub birth_date: Option<String>,
pub gender: Option<Gender>,
pub phone_number: Option<String>,
pub mobile_phone_number: Option<String>,
pub home_phone_number: Option<String>,
pub business_phone_number: Option<String>,
pub email_address: Option<String>,
pub personal_email_address: Option<String>,
pub business_email_address: Option<String>,
pub address: Option<Address>,
pub shipping_address: Option<Address>,
pub mailing_address: Option<Address>,
pub billing_address: Option<Address>,
pub attributes: Option<HashMap<String, String>>,
pub party_type_string: Option<String>,
pub gender_string: Option<String>,
pub profile_type: Option<ProfileType>,
pub engagement_preferences: Option<EngagementPreferences>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.domain_name: Option<String>The unique name of the domain.
account_number: Option<String>An account number that you have assigned to the customer.
additional_information: Option<String>Any additional information relevant to the customer’s profile.
party_type: Option<PartyType>The type of profile used to describe the customer.
business_name: Option<String>The name of the customer’s business.
first_name: Option<String>The customer’s first name.
middle_name: Option<String>The customer’s middle name.
last_name: Option<String>The customer’s last name.
birth_date: Option<String>The customer’s birth date.
gender: Option<Gender>The gender with which the customer identifies.
phone_number: Option<String>The customer’s phone number, which has not been specified as a mobile, home, or business number.
mobile_phone_number: Option<String>The customer’s mobile phone number.
home_phone_number: Option<String>The customer’s home phone number.
business_phone_number: Option<String>The customer’s business phone number.
email_address: Option<String>The customer’s email address, which has not been specified as a personal or business address.
personal_email_address: Option<String>The customer’s personal email address.
business_email_address: Option<String>The customer’s business email address.
address: Option<Address>A generic address associated with the customer that is not mailing, shipping, or billing.
shipping_address: Option<Address>The customer’s shipping address.
mailing_address: Option<Address>The customer’s mailing address.
billing_address: Option<Address>The customer’s billing address.
attributes: Option<HashMap<String, String>>A key value pair of attributes of a customer profile.
party_type_string: Option<String>An alternative to PartyType which accepts any string as input.
gender_string: Option<String>An alternative to Gender which accepts any string as input.
profile_type: Option<ProfileType>The type of the profile.
engagement_preferences: Option<EngagementPreferences>Object that defines the preferred methods of engagement, per channel.
Implementations
Sourceimpl CreateProfileInput
impl CreateProfileInput
Sourcepub fn domain_name(&self) -> Option<&str>
pub fn domain_name(&self) -> Option<&str>
The unique name of the domain.
Sourcepub fn account_number(&self) -> Option<&str>
pub fn account_number(&self) -> Option<&str>
An account number that you have assigned to the customer.
Sourcepub fn additional_information(&self) -> Option<&str>
pub fn additional_information(&self) -> Option<&str>
Any additional information relevant to the customer’s profile.
Sourcepub fn party_type(&self) -> Option<&PartyType>
pub fn party_type(&self) -> Option<&PartyType>
The type of profile used to describe the customer.
Sourcepub fn business_name(&self) -> Option<&str>
pub fn business_name(&self) -> Option<&str>
The name of the customer’s business.
Sourcepub fn first_name(&self) -> Option<&str>
pub fn first_name(&self) -> Option<&str>
The customer’s first name.
Sourcepub fn middle_name(&self) -> Option<&str>
pub fn middle_name(&self) -> Option<&str>
The customer’s middle name.
Sourcepub fn birth_date(&self) -> Option<&str>
pub fn birth_date(&self) -> Option<&str>
The customer’s birth date.
Sourcepub fn phone_number(&self) -> Option<&str>
pub fn phone_number(&self) -> Option<&str>
The customer’s phone number, which has not been specified as a mobile, home, or business number.
Sourcepub fn mobile_phone_number(&self) -> Option<&str>
pub fn mobile_phone_number(&self) -> Option<&str>
The customer’s mobile phone number.
Sourcepub fn home_phone_number(&self) -> Option<&str>
pub fn home_phone_number(&self) -> Option<&str>
The customer’s home phone number.
Sourcepub fn business_phone_number(&self) -> Option<&str>
pub fn business_phone_number(&self) -> Option<&str>
The customer’s business phone number.
Sourcepub fn email_address(&self) -> Option<&str>
pub fn email_address(&self) -> Option<&str>
The customer’s email address, which has not been specified as a personal or business address.
Sourcepub fn personal_email_address(&self) -> Option<&str>
pub fn personal_email_address(&self) -> Option<&str>
The customer’s personal email address.
Sourcepub fn business_email_address(&self) -> Option<&str>
pub fn business_email_address(&self) -> Option<&str>
The customer’s business email address.
Sourcepub fn address(&self) -> Option<&Address>
pub fn address(&self) -> Option<&Address>
A generic address associated with the customer that is not mailing, shipping, or billing.
Sourcepub fn shipping_address(&self) -> Option<&Address>
pub fn shipping_address(&self) -> Option<&Address>
The customer’s shipping address.
Sourcepub fn mailing_address(&self) -> Option<&Address>
pub fn mailing_address(&self) -> Option<&Address>
The customer’s mailing address.
Sourcepub fn billing_address(&self) -> Option<&Address>
pub fn billing_address(&self) -> Option<&Address>
The customer’s billing address.
Sourcepub fn attributes(&self) -> Option<&HashMap<String, String>>
pub fn attributes(&self) -> Option<&HashMap<String, String>>
A key value pair of attributes of a customer profile.
Sourcepub fn party_type_string(&self) -> Option<&str>
pub fn party_type_string(&self) -> Option<&str>
An alternative to PartyType which accepts any string as input.
Sourcepub fn gender_string(&self) -> Option<&str>
pub fn gender_string(&self) -> Option<&str>
An alternative to Gender which accepts any string as input.
Sourcepub fn profile_type(&self) -> Option<&ProfileType>
pub fn profile_type(&self) -> Option<&ProfileType>
The type of the profile.
Sourcepub fn engagement_preferences(&self) -> Option<&EngagementPreferences>
pub fn engagement_preferences(&self) -> Option<&EngagementPreferences>
Object that defines the preferred methods of engagement, per channel.
Sourceimpl CreateProfileInput
impl CreateProfileInput
Sourcepub fn builder() -> CreateProfileInputBuilder
pub fn builder() -> CreateProfileInputBuilder
Creates a new builder-style object to manufacture CreateProfileInput.