#[non_exhaustive]pub struct CreateSegmentDefinitionInput {
pub domain_name: Option<String>,
pub segment_definition_name: Option<String>,
pub display_name: Option<String>,
pub description: Option<String>,
pub segment_groups: Option<SegmentGroup>,
pub segment_sql_query: Option<String>,
pub segment_sort: Option<SegmentSort>,
pub tags: Option<HashMap<String, String>>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.domain_name: Option<String>The unique name of the domain.
segment_definition_name: Option<String>The unique name of the segment definition.
display_name: Option<String>The display name of the segment definition.
description: Option<String>The description of the segment definition.
segment_groups: Option<SegmentGroup>Specifies the base segments and dimensions for a segment definition along with their respective relationship.
segment_sql_query: Option<String>The segment SQL query.
segment_sort: Option<SegmentSort>The segment sort.
The tags used to organize, track, or control access for this resource.
Implementations
Sourceimpl CreateSegmentDefinitionInput
impl CreateSegmentDefinitionInput
Sourcepub fn domain_name(&self) -> Option<&str>
pub fn domain_name(&self) -> Option<&str>
The unique name of the domain.
Sourcepub fn segment_definition_name(&self) -> Option<&str>
pub fn segment_definition_name(&self) -> Option<&str>
The unique name of the segment definition.
Sourcepub fn display_name(&self) -> Option<&str>
pub fn display_name(&self) -> Option<&str>
The display name of the segment definition.
Sourcepub fn description(&self) -> Option<&str>
pub fn description(&self) -> Option<&str>
The description of the segment definition.
Sourcepub fn segment_groups(&self) -> Option<&SegmentGroup>
pub fn segment_groups(&self) -> Option<&SegmentGroup>
Specifies the base segments and dimensions for a segment definition along with their respective relationship.
Sourcepub fn segment_sql_query(&self) -> Option<&str>
pub fn segment_sql_query(&self) -> Option<&str>
The segment SQL query.
Sourcepub fn segment_sort(&self) -> Option<&SegmentSort>
pub fn segment_sort(&self) -> Option<&SegmentSort>
The segment sort.
The tags used to organize, track, or control access for this resource.
Sourceimpl CreateSegmentDefinitionInput
impl CreateSegmentDefinitionInput
Sourcepub fn builder() -> CreateSegmentDefinitionInputBuilder
pub fn builder() -> CreateSegmentDefinitionInputBuilder
Creates a new builder-style object to manufacture CreateSegmentDefinitionInput.