#[non_exhaustive]pub struct GetObjectTypeAttributeStatisticsStatsBuilder { /* private fields */ }Expand description
A builder for GetObjectTypeAttributeStatisticsStats.
Implementations
Sourceimpl GetObjectTypeAttributeStatisticsStatsBuilder
impl GetObjectTypeAttributeStatisticsStatsBuilder
Sourcepub fn maximum(self, input: f64) -> Self
pub fn maximum(self, input: f64) -> Self
The maximum value found in the attribute dataset.
This field is required.Sourcepub fn set_maximum(self, input: Option<f64>) -> Self
pub fn set_maximum(self, input: Option<f64>) -> Self
The maximum value found in the attribute dataset.
Sourcepub fn get_maximum(&self) -> &Option<f64>
pub fn get_maximum(&self) -> &Option<f64>
The maximum value found in the attribute dataset.
Sourcepub fn minimum(self, input: f64) -> Self
pub fn minimum(self, input: f64) -> Self
The minimum value found in the attribute dataset.
This field is required.Sourcepub fn set_minimum(self, input: Option<f64>) -> Self
pub fn set_minimum(self, input: Option<f64>) -> Self
The minimum value found in the attribute dataset.
Sourcepub fn get_minimum(&self) -> &Option<f64>
pub fn get_minimum(&self) -> &Option<f64>
The minimum value found in the attribute dataset.
Sourcepub fn average(self, input: f64) -> Self
pub fn average(self, input: f64) -> Self
The arithmetic mean of the attribute values.
This field is required.Sourcepub fn set_average(self, input: Option<f64>) -> Self
pub fn set_average(self, input: Option<f64>) -> Self
The arithmetic mean of the attribute values.
Sourcepub fn get_average(&self) -> &Option<f64>
pub fn get_average(&self) -> &Option<f64>
The arithmetic mean of the attribute values.
Sourcepub fn standard_deviation(self, input: f64) -> Self
pub fn standard_deviation(self, input: f64) -> Self
The standard deviation of the attribute values, measuring their spread around the mean.
This field is required.Sourcepub fn set_standard_deviation(self, input: Option<f64>) -> Self
pub fn set_standard_deviation(self, input: Option<f64>) -> Self
The standard deviation of the attribute values, measuring their spread around the mean.
Sourcepub fn get_standard_deviation(&self) -> &Option<f64>
pub fn get_standard_deviation(&self) -> &Option<f64>
The standard deviation of the attribute values, measuring their spread around the mean.
Sourcepub fn percentiles(
self,
input: GetObjectTypeAttributeStatisticsPercentiles,
) -> Self
pub fn percentiles( self, input: GetObjectTypeAttributeStatisticsPercentiles, ) -> Self
Percentile distribution statistics for the attribute values.
This field is required.Sourcepub fn set_percentiles(
self,
input: Option<GetObjectTypeAttributeStatisticsPercentiles>,
) -> Self
pub fn set_percentiles( self, input: Option<GetObjectTypeAttributeStatisticsPercentiles>, ) -> Self
Percentile distribution statistics for the attribute values.
Sourcepub fn get_percentiles(
&self,
) -> &Option<GetObjectTypeAttributeStatisticsPercentiles>
pub fn get_percentiles( &self, ) -> &Option<GetObjectTypeAttributeStatisticsPercentiles>
Percentile distribution statistics for the attribute values.
Sourcepub fn build(self) -> Result<GetObjectTypeAttributeStatisticsStats, BuildError>
pub fn build(self) -> Result<GetObjectTypeAttributeStatisticsStats, BuildError>
Consumes the builder and constructs a GetObjectTypeAttributeStatisticsStats.
This method will fail if any of the following fields are not set: