#[non_exhaustive]pub struct AppflowIntegrationWorkflowAttributes {
pub source_connector_type: SourceConnectorType,
pub connector_profile_name: String,
pub role_arn: Option<String>,
}Expand description
Structure holding all APPFLOW_INTEGRATION specific workflow attributes.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.source_connector_type: SourceConnectorTypeSpecifies the source connector type, such as Salesforce, ServiceNow, and Marketo. Indicates source of ingestion.
connector_profile_name: StringThe name of the AppFlow connector profile used for ingestion.
role_arn: Option<String>The Amazon Resource Name (ARN) of the IAM role. Customer Profiles assumes this role to create resources on your behalf as part of workflow execution.
Implementations
Sourceimpl AppflowIntegrationWorkflowAttributes
impl AppflowIntegrationWorkflowAttributes
Sourcepub fn source_connector_type(&self) -> &SourceConnectorType
pub fn source_connector_type(&self) -> &SourceConnectorType
Specifies the source connector type, such as Salesforce, ServiceNow, and Marketo. Indicates source of ingestion.
Sourcepub fn connector_profile_name(&self) -> &str
pub fn connector_profile_name(&self) -> &str
The name of the AppFlow connector profile used for ingestion.
Sourceimpl AppflowIntegrationWorkflowAttributes
impl AppflowIntegrationWorkflowAttributes
Sourcepub fn builder() -> AppflowIntegrationWorkflowAttributesBuilder
pub fn builder() -> AppflowIntegrationWorkflowAttributesBuilder
Creates a new builder-style object to manufacture AppflowIntegrationWorkflowAttributes.