#[non_exhaustive]pub struct AppflowIntegrationWorkflowStep {
pub flow_name: String,
pub status: Status,
pub execution_message: String,
pub records_processed: i64,
pub batch_records_start_time: String,
pub batch_records_end_time: String,
pub created_at: DateTime,
pub last_updated_at: DateTime,
}Expand description
Workflow step details for APPFLOW_INTEGRATION workflow.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.flow_name: StringName of the flow created during execution of workflow step. APPFLOW_INTEGRATION workflow type creates an appflow flow during workflow step execution on the customers behalf.
status: StatusWorkflow step status for APPFLOW_INTEGRATION workflow.
execution_message: StringMessage indicating execution of workflow step for APPFLOW_INTEGRATION workflow.
records_processed: i64Total number of records processed during execution of workflow step for APPFLOW_INTEGRATION workflow.
batch_records_start_time: StringStart datetime of records pulled in batch during execution of workflow step for APPFLOW_INTEGRATION workflow.
batch_records_end_time: StringEnd datetime of records pulled in batch during execution of workflow step for APPFLOW_INTEGRATION workflow.
created_at: DateTimeCreation timestamp of workflow step for APPFLOW_INTEGRATION workflow.
last_updated_at: DateTimeLast updated timestamp for workflow step for APPFLOW_INTEGRATION workflow.
Implementations
Sourceimpl AppflowIntegrationWorkflowStep
impl AppflowIntegrationWorkflowStep
Sourcepub fn flow_name(&self) -> &str
pub fn flow_name(&self) -> &str
Name of the flow created during execution of workflow step. APPFLOW_INTEGRATION workflow type creates an appflow flow during workflow step execution on the customers behalf.
Sourcepub fn execution_message(&self) -> &str
pub fn execution_message(&self) -> &str
Message indicating execution of workflow step for APPFLOW_INTEGRATION workflow.
Sourcepub fn records_processed(&self) -> i64
pub fn records_processed(&self) -> i64
Total number of records processed during execution of workflow step for APPFLOW_INTEGRATION workflow.
Sourcepub fn batch_records_start_time(&self) -> &str
pub fn batch_records_start_time(&self) -> &str
Start datetime of records pulled in batch during execution of workflow step for APPFLOW_INTEGRATION workflow.
Sourcepub fn batch_records_end_time(&self) -> &str
pub fn batch_records_end_time(&self) -> &str
End datetime of records pulled in batch during execution of workflow step for APPFLOW_INTEGRATION workflow.
Sourcepub fn created_at(&self) -> &DateTime
pub fn created_at(&self) -> &DateTime
Creation timestamp of workflow step for APPFLOW_INTEGRATION workflow.
Sourcepub fn last_updated_at(&self) -> &DateTime
pub fn last_updated_at(&self) -> &DateTime
Last updated timestamp for workflow step for APPFLOW_INTEGRATION workflow.
Sourceimpl AppflowIntegrationWorkflowStep
impl AppflowIntegrationWorkflowStep
Sourcepub fn builder() -> AppflowIntegrationWorkflowStepBuilder
pub fn builder() -> AppflowIntegrationWorkflowStepBuilder
Creates a new builder-style object to manufacture AppflowIntegrationWorkflowStep.