#[non_exhaustive]pub struct AutoMerging {
pub enabled: bool,
pub consolidation: Option<Consolidation>,
pub conflict_resolution: Option<ConflictResolution>,
pub min_allowed_confidence_score_for_merging: Option<f64>,
}Expand description
Configuration settings for how to perform the auto-merging of profiles.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.enabled: boolThe flag that enables the auto-merging of duplicate profiles.
consolidation: Option<Consolidation>A list of matching attributes that represent matching criteria. If two profiles meet at least one of the requirements in the matching attributes list, they will be merged.
conflict_resolution: Option<ConflictResolution>How the auto-merging process should resolve conflicts between different profiles. For example, if Profile A and Profile B have the same FirstName and LastName (and that is the matching criteria), which EmailAddress should be used?
min_allowed_confidence_score_for_merging: Option<f64>A number between 0 and 1 that represents the minimum confidence score required for profiles within a matching group to be merged during the auto-merge process. A higher score means higher similarity required to merge profiles.
Implementations
Sourceimpl AutoMerging
impl AutoMerging
Sourcepub fn consolidation(&self) -> Option<&Consolidation>
pub fn consolidation(&self) -> Option<&Consolidation>
A list of matching attributes that represent matching criteria. If two profiles meet at least one of the requirements in the matching attributes list, they will be merged.
Sourcepub fn conflict_resolution(&self) -> Option<&ConflictResolution>
pub fn conflict_resolution(&self) -> Option<&ConflictResolution>
How the auto-merging process should resolve conflicts between different profiles. For example, if Profile A and Profile B have the same FirstName and LastName (and that is the matching criteria), which EmailAddress should be used?
Sourcepub fn min_allowed_confidence_score_for_merging(&self) -> Option<f64>
pub fn min_allowed_confidence_score_for_merging(&self) -> Option<f64>
A number between 0 and 1 that represents the minimum confidence score required for profiles within a matching group to be merged during the auto-merge process. A higher score means higher similarity required to merge profiles.
Sourceimpl AutoMerging
impl AutoMerging
Sourcepub fn builder() -> AutoMergingBuilder
pub fn builder() -> AutoMergingBuilder
Creates a new builder-style object to manufacture AutoMerging.