#[non_exhaustive]pub struct CalculatedAttributeValue {
pub calculated_attribute_name: Option<String>,
pub display_name: Option<String>,
pub is_data_partial: Option<String>,
pub profile_id: Option<String>,
pub value: Option<String>,
pub last_object_timestamp: Option<DateTime>,
}Expand description
The object containing the values of a single calculated attribute value.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.calculated_attribute_name: Option<String>The unique name of the calculated attribute.
display_name: Option<String>The display name of the calculated attribute.
is_data_partial: Option<String>Indicates whether the calculated attribute's value is based on partial data. If the data is partial, it is set to true.
profile_id: Option<String>The profile id belonging to this calculated attribute value.
value: Option<String>The value of the calculated attribute.
last_object_timestamp: Option<DateTime>The timestamp of the newest object included in the calculated attribute calculation.
Implementations
Sourceimpl CalculatedAttributeValue
impl CalculatedAttributeValue
Sourcepub fn calculated_attribute_name(&self) -> Option<&str>
pub fn calculated_attribute_name(&self) -> Option<&str>
The unique name of the calculated attribute.
Sourcepub fn display_name(&self) -> Option<&str>
pub fn display_name(&self) -> Option<&str>
The display name of the calculated attribute.
Sourcepub fn is_data_partial(&self) -> Option<&str>
pub fn is_data_partial(&self) -> Option<&str>
Indicates whether the calculated attribute's value is based on partial data. If the data is partial, it is set to true.
Sourcepub fn profile_id(&self) -> Option<&str>
pub fn profile_id(&self) -> Option<&str>
The profile id belonging to this calculated attribute value.
Sourcepub fn last_object_timestamp(&self) -> Option<&DateTime>
pub fn last_object_timestamp(&self) -> Option<&DateTime>
The timestamp of the newest object included in the calculated attribute calculation.
Sourceimpl CalculatedAttributeValue
impl CalculatedAttributeValue
Sourcepub fn builder() -> CalculatedAttributeValueBuilder
pub fn builder() -> CalculatedAttributeValueBuilder
Creates a new builder-style object to manufacture CalculatedAttributeValue.