#[non_exhaustive]pub struct ConflictResolution {
pub conflict_resolving_model: ConflictResolvingModel,
pub source_name: Option<String>,
}Expand description
How the auto-merging process should resolve conflicts between different profiles.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.conflict_resolving_model: ConflictResolvingModelHow the auto-merging process should resolve conflicts between different profiles.
-
RECENCY: Uses the data that was most recently updated. -
SOURCE: Uses the data from a specific source. For example, if a company has been aquired or two departments have merged, data from the specified source is used. If two duplicate profiles are from the same source, thenRECENCYis used again.
source_name: Option<String>The ObjectType name that is used to resolve profile merging conflicts when choosing SOURCE as the ConflictResolvingModel.
Implementations
Sourceimpl ConflictResolution
impl ConflictResolution
Sourcepub fn conflict_resolving_model(&self) -> &ConflictResolvingModel
pub fn conflict_resolving_model(&self) -> &ConflictResolvingModel
How the auto-merging process should resolve conflicts between different profiles.
-
RECENCY: Uses the data that was most recently updated. -
SOURCE: Uses the data from a specific source. For example, if a company has been aquired or two departments have merged, data from the specified source is used. If two duplicate profiles are from the same source, thenRECENCYis used again.
Sourcepub fn source_name(&self) -> Option<&str>
pub fn source_name(&self) -> Option<&str>
The ObjectType name that is used to resolve profile merging conflicts when choosing SOURCE as the ConflictResolvingModel.
Sourceimpl ConflictResolution
impl ConflictResolution
Sourcepub fn builder() -> ConflictResolutionBuilder
pub fn builder() -> ConflictResolutionBuilder
Creates a new builder-style object to manufacture ConflictResolution.