#[non_exhaustive]pub struct DomainStats {
pub profile_count: i64,
pub metering_profile_count: i64,
pub object_count: i64,
pub total_size: i64,
}Expand description
Usage-specific statistics about the domain.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.profile_count: i64The total number of profiles currently in the domain.
metering_profile_count: i64The number of profiles that you are currently paying for in the domain. If you have more than 100 objects associated with a single profile, that profile counts as two profiles. If you have more than 200 objects, that profile counts as three, and so on.
object_count: i64The total number of objects in domain.
total_size: i64The total size, in bytes, of all objects in the domain.
Implementations
Sourceimpl DomainStats
impl DomainStats
Sourcepub fn profile_count(&self) -> i64
pub fn profile_count(&self) -> i64
The total number of profiles currently in the domain.
Sourcepub fn metering_profile_count(&self) -> i64
pub fn metering_profile_count(&self) -> i64
The number of profiles that you are currently paying for in the domain. If you have more than 100 objects associated with a single profile, that profile counts as two profiles. If you have more than 200 objects, that profile counts as three, and so on.
Sourcepub fn object_count(&self) -> i64
pub fn object_count(&self) -> i64
The total number of objects in domain.
Sourcepub fn total_size(&self) -> i64
pub fn total_size(&self) -> i64
The total size, in bytes, of all objects in the domain.
Sourceimpl DomainStats
impl DomainStats
Sourcepub fn builder() -> DomainStatsBuilder
pub fn builder() -> DomainStatsBuilder
Creates a new builder-style object to manufacture DomainStats.