#[non_exhaustive]pub struct EventParameters {
pub event_type: String,
pub event_value_threshold: Option<f64>,
pub event_weight: Option<f64>,
}Expand description
Configuration parameters for events in the personalization system.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.event_type: StringThe type of event being tracked (e.g., 'click', 'purchase', 'view').
event_value_threshold: Option<f64>The minimum value threshold that an event must meet to be considered valid.
event_weight: Option<f64>The weight of the event type. A higher weight means higher importance of the event type for the created solution.
Implementations
Sourceimpl EventParameters
impl EventParameters
Sourcepub fn event_type(&self) -> &str
pub fn event_type(&self) -> &str
The type of event being tracked (e.g., 'click', 'purchase', 'view').
Sourcepub fn event_value_threshold(&self) -> Option<f64>
pub fn event_value_threshold(&self) -> Option<f64>
The minimum value threshold that an event must meet to be considered valid.
Sourcepub fn event_weight(&self) -> Option<f64>
pub fn event_weight(&self) -> Option<f64>
The weight of the event type. A higher weight means higher importance of the event type for the created solution.
Sourceimpl EventParameters
impl EventParameters
Sourcepub fn builder() -> EventParametersBuilder
pub fn builder() -> EventParametersBuilder
Creates a new builder-style object to manufacture EventParameters.