#[non_exhaustive]pub struct FlowDefinition {
pub description: Option<String>,
pub flow_name: String,
pub kms_arn: String,
pub source_flow_config: Option<SourceFlowConfig>,
pub tasks: Vec<Task>,
pub trigger_config: Option<TriggerConfig>,
}Expand description
The configurations that control how Customer Profiles retrieves data from the source, Amazon AppFlow. Customer Profiles uses this information to create an AppFlow flow on behalf of customers.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.description: Option<String>A description of the flow you want to create.
flow_name: StringThe specified name of the flow. Use underscores (_) or hyphens (-) only. Spaces are not allowed.
kms_arn: StringThe Amazon Resource Name of the AWS Key Management Service (KMS) key you provide for encryption.
source_flow_config: Option<SourceFlowConfig>The configuration that controls how Customer Profiles retrieves data from the source.
tasks: Vec<Task>A list of tasks that Customer Profiles performs while transferring the data in the flow run.
trigger_config: Option<TriggerConfig>The trigger settings that determine how and when the flow runs.
Implementations
Sourceimpl FlowDefinition
impl FlowDefinition
Sourcepub fn description(&self) -> Option<&str>
pub fn description(&self) -> Option<&str>
A description of the flow you want to create.
Sourcepub fn flow_name(&self) -> &str
pub fn flow_name(&self) -> &str
The specified name of the flow. Use underscores (_) or hyphens (-) only. Spaces are not allowed.
Sourcepub fn kms_arn(&self) -> &str
pub fn kms_arn(&self) -> &str
The Amazon Resource Name of the AWS Key Management Service (KMS) key you provide for encryption.
Sourcepub fn source_flow_config(&self) -> Option<&SourceFlowConfig>
pub fn source_flow_config(&self) -> Option<&SourceFlowConfig>
The configuration that controls how Customer Profiles retrieves data from the source.
Sourcepub fn tasks(&self) -> &[Task]
pub fn tasks(&self) -> &[Task]
A list of tasks that Customer Profiles performs while transferring the data in the flow run.
Sourcepub fn trigger_config(&self) -> Option<&TriggerConfig>
pub fn trigger_config(&self) -> Option<&TriggerConfig>
The trigger settings that determine how and when the flow runs.
Sourceimpl FlowDefinition
impl FlowDefinition
Sourcepub fn builder() -> FlowDefinitionBuilder
pub fn builder() -> FlowDefinitionBuilder
Creates a new builder-style object to manufacture FlowDefinition.