#[non_exhaustive]pub struct FoundByKeyValue {
pub key_name: Option<String>,
pub values: Option<Vec<String>>,
}Expand description
A data type pair that consists of a KeyName and Values list that were used to find a profile returned in response to a SearchProfiles request.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.key_name: Option<String>A searchable identifier of a customer profile.
values: Option<Vec<String>>A list of key values.
Implementations
Sourceimpl FoundByKeyValue
impl FoundByKeyValue
Sourcepub fn builder() -> FoundByKeyValueBuilder
pub fn builder() -> FoundByKeyValueBuilder
Creates a new builder-style object to manufacture FoundByKeyValue.