#[non_exhaustive]pub struct GetObjectTypeAttributeStatisticsStats {
pub maximum: f64,
pub minimum: f64,
pub average: f64,
pub standard_deviation: f64,
pub percentiles: Option<GetObjectTypeAttributeStatisticsPercentiles>,
}Expand description
Statistical measurements for object type attributes including basic statistics and percentiles.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.maximum: f64The maximum value found in the attribute dataset.
minimum: f64The minimum value found in the attribute dataset.
average: f64The arithmetic mean of the attribute values.
standard_deviation: f64The standard deviation of the attribute values, measuring their spread around the mean.
percentiles: Option<GetObjectTypeAttributeStatisticsPercentiles>Percentile distribution statistics for the attribute values.
Implementations
Sourceimpl GetObjectTypeAttributeStatisticsStats
impl GetObjectTypeAttributeStatisticsStats
Sourcepub fn standard_deviation(&self) -> f64
pub fn standard_deviation(&self) -> f64
The standard deviation of the attribute values, measuring their spread around the mean.
Sourcepub fn percentiles(
&self,
) -> Option<&GetObjectTypeAttributeStatisticsPercentiles>
pub fn percentiles( &self, ) -> Option<&GetObjectTypeAttributeStatisticsPercentiles>
Percentile distribution statistics for the attribute values.
Sourceimpl GetObjectTypeAttributeStatisticsStats
impl GetObjectTypeAttributeStatisticsStats
Sourcepub fn builder() -> GetObjectTypeAttributeStatisticsStatsBuilder
pub fn builder() -> GetObjectTypeAttributeStatisticsStatsBuilder
Creates a new builder-style object to manufacture GetObjectTypeAttributeStatisticsStats.