#[non_exhaustive]pub struct MatchingResponse {
pub enabled: Option<bool>,
pub job_schedule: Option<JobSchedule>,
pub auto_merging: Option<AutoMerging>,
pub exporting_config: Option<ExportingConfig>,
}Expand description
The flag that enables the matching process of duplicate profiles.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.enabled: Option<bool>The flag that enables the matching process of duplicate profiles.
job_schedule: Option<JobSchedule>The day and time when do you want to start the Identity Resolution Job every week.
auto_merging: Option<AutoMerging>Configuration information about the auto-merging process.
exporting_config: Option<ExportingConfig>Configuration information for exporting Identity Resolution results, for example, to an S3 bucket.
Implementations
Sourceimpl MatchingResponse
impl MatchingResponse
Sourcepub fn enabled(&self) -> Option<bool>
pub fn enabled(&self) -> Option<bool>
The flag that enables the matching process of duplicate profiles.
Sourcepub fn job_schedule(&self) -> Option<&JobSchedule>
pub fn job_schedule(&self) -> Option<&JobSchedule>
The day and time when do you want to start the Identity Resolution Job every week.
Sourcepub fn auto_merging(&self) -> Option<&AutoMerging>
pub fn auto_merging(&self) -> Option<&AutoMerging>
Configuration information about the auto-merging process.
Sourcepub fn exporting_config(&self) -> Option<&ExportingConfig>
pub fn exporting_config(&self) -> Option<&ExportingConfig>
Configuration information for exporting Identity Resolution results, for example, to an S3 bucket.
Sourceimpl MatchingResponse
impl MatchingResponse
Sourcepub fn builder() -> MatchingResponseBuilder
pub fn builder() -> MatchingResponseBuilder
Creates a new builder-style object to manufacture MatchingResponse.