#[non_exhaustive]pub struct ObjectAttribute {
pub source: Option<String>,
pub field_name: Option<String>,
pub comparison_operator: ComparisonOperator,
pub values: Vec<String>,
}Expand description
The criteria that a specific object attribute must meet to trigger the destination.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.source: Option<String>An attribute contained within a source object.
field_name: Option<String>A field defined within an object type.
comparison_operator: ComparisonOperatorThe operator used to compare an attribute against a list of values.
values: Vec<String>A list of attribute values used for comparison.
Implementations
Sourceimpl ObjectAttribute
impl ObjectAttribute
Sourcepub fn field_name(&self) -> Option<&str>
pub fn field_name(&self) -> Option<&str>
A field defined within an object type.
Sourcepub fn comparison_operator(&self) -> &ComparisonOperator
pub fn comparison_operator(&self) -> &ComparisonOperator
The operator used to compare an attribute against a list of values.
Sourceimpl ObjectAttribute
impl ObjectAttribute
Sourcepub fn builder() -> ObjectAttributeBuilder
pub fn builder() -> ObjectAttributeBuilder
Creates a new builder-style object to manufacture ObjectAttribute.