#[non_exhaustive]pub struct ObjectTypeField {
pub source: Option<String>,
pub target: Option<String>,
pub content_type: Option<FieldContentType>,
}Expand description
Represents a field in a ProfileObjectType.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.source: Option<String>A field of a ProfileObject. For example: _source.FirstName, where “_source” is a ProfileObjectType of a Zendesk user and “FirstName” is a field in that ObjectType.
target: Option<String>The location of the data in the standard ProfileObject model. For example: _profile.Address.PostalCode. Do not include sensitive or personally identifiable information (PII) in the target field name.
content_type: Option<FieldContentType>The content type of the field. Used for determining equality when searching.
Implementations
Sourceimpl ObjectTypeField
impl ObjectTypeField
Sourcepub fn source(&self) -> Option<&str>
pub fn source(&self) -> Option<&str>
A field of a ProfileObject. For example: _source.FirstName, where “_source” is a ProfileObjectType of a Zendesk user and “FirstName” is a field in that ObjectType.
Sourcepub fn target(&self) -> Option<&str>
pub fn target(&self) -> Option<&str>
The location of the data in the standard ProfileObject model. For example: _profile.Address.PostalCode. Do not include sensitive or personally identifiable information (PII) in the target field name.
Sourcepub fn content_type(&self) -> Option<&FieldContentType>
pub fn content_type(&self) -> Option<&FieldContentType>
The content type of the field. Used for determining equality when searching.
Sourceimpl ObjectTypeField
impl ObjectTypeField
Sourcepub fn builder() -> ObjectTypeFieldBuilder
pub fn builder() -> ObjectTypeFieldBuilder
Creates a new builder-style object to manufacture ObjectTypeField.