#[non_exhaustive]pub struct RuleBasedMatchingRequest {
pub enabled: bool,
pub matching_rules: Option<Vec<MatchingRule>>,
pub max_allowed_rule_level_for_merging: Option<i32>,
pub max_allowed_rule_level_for_matching: Option<i32>,
pub attribute_types_selector: Option<AttributeTypesSelector>,
pub conflict_resolution: Option<ConflictResolution>,
pub exporting_config: Option<ExportingConfig>,
}Expand description
The request to enable the rule-based matching.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.enabled: boolThe flag that enables the rule-based matching process of duplicate profiles.
matching_rules: Option<Vec<MatchingRule>>Configures how the rule-based matching process should match profiles. You can have up to 15 MatchingRule in the MatchingRules.
max_allowed_rule_level_for_merging: Option<i32>max_allowed_rule_level_for_matching: Option<i32>Indicates the maximum allowed rule level.
attribute_types_selector: Option<AttributeTypesSelector>Configures information about the AttributeTypesSelector where the rule-based identity resolution uses to match profiles.
conflict_resolution: Option<ConflictResolution>How the auto-merging process should resolve conflicts between different profiles.
exporting_config: Option<ExportingConfig>Configuration information about the S3 bucket where Identity Resolution Jobs writes result files.
You need to give Customer Profiles service principal write permission to your S3 bucket. Otherwise, you'll get an exception in the API response. For an example policy, see Amazon Connect Customer Profiles cross-service confused deputy prevention.
Implementations
Sourceimpl RuleBasedMatchingRequest
impl RuleBasedMatchingRequest
Sourcepub fn enabled(&self) -> bool
pub fn enabled(&self) -> bool
The flag that enables the rule-based matching process of duplicate profiles.
Sourcepub fn matching_rules(&self) -> &[MatchingRule]
pub fn matching_rules(&self) -> &[MatchingRule]
Configures how the rule-based matching process should match profiles. You can have up to 15 MatchingRule in the MatchingRules.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .matching_rules.is_none().
Sourcepub fn max_allowed_rule_level_for_merging(&self) -> Option<i32>
pub fn max_allowed_rule_level_for_merging(&self) -> Option<i32>
Sourcepub fn max_allowed_rule_level_for_matching(&self) -> Option<i32>
pub fn max_allowed_rule_level_for_matching(&self) -> Option<i32>
Indicates the maximum allowed rule level.
Sourcepub fn attribute_types_selector(&self) -> Option<&AttributeTypesSelector>
pub fn attribute_types_selector(&self) -> Option<&AttributeTypesSelector>
Configures information about the AttributeTypesSelector where the rule-based identity resolution uses to match profiles.
Sourcepub fn conflict_resolution(&self) -> Option<&ConflictResolution>
pub fn conflict_resolution(&self) -> Option<&ConflictResolution>
How the auto-merging process should resolve conflicts between different profiles.
Sourcepub fn exporting_config(&self) -> Option<&ExportingConfig>
pub fn exporting_config(&self) -> Option<&ExportingConfig>
Configuration information about the S3 bucket where Identity Resolution Jobs writes result files.
You need to give Customer Profiles service principal write permission to your S3 bucket. Otherwise, you'll get an exception in the API response. For an example policy, see Amazon Connect Customer Profiles cross-service confused deputy prevention.
Sourceimpl RuleBasedMatchingRequest
impl RuleBasedMatchingRequest
Sourcepub fn builder() -> RuleBasedMatchingRequestBuilder
pub fn builder() -> RuleBasedMatchingRequestBuilder
Creates a new builder-style object to manufacture RuleBasedMatchingRequest.