#[non_exhaustive]pub struct RuleBasedMatchingResponse {
pub enabled: Option<bool>,
pub matching_rules: Option<Vec<MatchingRule>>,
pub status: Option<RuleBasedMatchingStatus>,
pub max_allowed_rule_level_for_merging: Option<i32>,
pub max_allowed_rule_level_for_matching: Option<i32>,
pub attribute_types_selector: Option<AttributeTypesSelector>,
pub conflict_resolution: Option<ConflictResolution>,
pub exporting_config: Option<ExportingConfig>,
}Expand description
The response of the Rule-based matching request.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.enabled: Option<bool>The flag that enables the rule-based matching process of duplicate profiles.
matching_rules: Option<Vec<MatchingRule>>Configures how the rule-based matching process should match profiles. You can have up to 15 MatchingRule in the MatchingRules.
status: Option<RuleBasedMatchingStatus>PENDING
-
The first status after configuration a rule-based matching rule. If it is an existing domain, the rule-based Identity Resolution waits one hour before creating the matching rule. If it is a new domain, the system will skip the
PENDINGstage.
IN_PROGRESS
-
The system is creating the rule-based matching rule. Under this status, the system is evaluating the existing data and you can no longer change the Rule-based matching configuration.
ACTIVE
-
The rule is ready to use. You can change the rule a day after the status is in
ACTIVE.
max_allowed_rule_level_for_merging: Option<i32>max_allowed_rule_level_for_matching: Option<i32>Indicates the maximum allowed rule level.
attribute_types_selector: Option<AttributeTypesSelector>Configures information about the AttributeTypesSelector where the rule-based identity resolution uses to match profiles.
conflict_resolution: Option<ConflictResolution>How the auto-merging process should resolve conflicts between different profiles.
exporting_config: Option<ExportingConfig>Configuration information about the S3 bucket where Identity Resolution Jobs writes result files.
You need to give Customer Profiles service principal write permission to your S3 bucket. Otherwise, you'll get an exception in the API response. For an example policy, see Amazon Connect Customer Profiles cross-service confused deputy prevention.
Implementations
Sourceimpl RuleBasedMatchingResponse
impl RuleBasedMatchingResponse
Sourcepub fn enabled(&self) -> Option<bool>
pub fn enabled(&self) -> Option<bool>
The flag that enables the rule-based matching process of duplicate profiles.
Sourcepub fn matching_rules(&self) -> &[MatchingRule]
pub fn matching_rules(&self) -> &[MatchingRule]
Configures how the rule-based matching process should match profiles. You can have up to 15 MatchingRule in the MatchingRules.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .matching_rules.is_none().
Sourcepub fn status(&self) -> Option<&RuleBasedMatchingStatus>
pub fn status(&self) -> Option<&RuleBasedMatchingStatus>
PENDING
-
The first status after configuration a rule-based matching rule. If it is an existing domain, the rule-based Identity Resolution waits one hour before creating the matching rule. If it is a new domain, the system will skip the
PENDINGstage.
IN_PROGRESS
-
The system is creating the rule-based matching rule. Under this status, the system is evaluating the existing data and you can no longer change the Rule-based matching configuration.
ACTIVE
-
The rule is ready to use. You can change the rule a day after the status is in
ACTIVE.
Sourcepub fn max_allowed_rule_level_for_merging(&self) -> Option<i32>
pub fn max_allowed_rule_level_for_merging(&self) -> Option<i32>
Sourcepub fn max_allowed_rule_level_for_matching(&self) -> Option<i32>
pub fn max_allowed_rule_level_for_matching(&self) -> Option<i32>
Indicates the maximum allowed rule level.
Sourcepub fn attribute_types_selector(&self) -> Option<&AttributeTypesSelector>
pub fn attribute_types_selector(&self) -> Option<&AttributeTypesSelector>
Configures information about the AttributeTypesSelector where the rule-based identity resolution uses to match profiles.
Sourcepub fn conflict_resolution(&self) -> Option<&ConflictResolution>
pub fn conflict_resolution(&self) -> Option<&ConflictResolution>
How the auto-merging process should resolve conflicts between different profiles.
Sourcepub fn exporting_config(&self) -> Option<&ExportingConfig>
pub fn exporting_config(&self) -> Option<&ExportingConfig>
Configuration information about the S3 bucket where Identity Resolution Jobs writes result files.
You need to give Customer Profiles service principal write permission to your S3 bucket. Otherwise, you'll get an exception in the API response. For an example policy, see Amazon Connect Customer Profiles cross-service confused deputy prevention.
Sourceimpl RuleBasedMatchingResponse
impl RuleBasedMatchingResponse
Sourcepub fn builder() -> RuleBasedMatchingResponseBuilder
pub fn builder() -> RuleBasedMatchingResponseBuilder
Creates a new builder-style object to manufacture RuleBasedMatchingResponse.